# Invalid Name Format

The name field contains uppercase letters and spaces. Valid names are
lowercase, alphanumeric, and hyphen-separated.

Expected error (Stage 2 -- Identity):
  ERROR: name must match lowercase alphanumeric with hyphens

Run: `agent pack .`
